# Benchmarks

This directory contains files that will be run via continuous testing either
nightly or after committing code to a pull request. 

The runtime and/or memory usage of the functions defined in these files will be
tracked and reported to give you a sense of the overall performance of your code.

You are encouraged to add, update, or remove benchmark functions to suit the needs
of your project.

For more information, see the documentation here: https://lincc-ppt.readthedocs.io/en/latest/practices/ci_benchmarking.html